function QTDOnRGBImage(RGBImage,NIter,MaxDeltaRGB);

% Dimensioni dell'immagine
[NRow,NCol,NChannels]=size(RGBImage);

% Controllo sulle dimensioni dell'immagine
if (NRow~=NCol)
    disp('Not sqaured image!');
    return;
end
if (mod(NRow,2)~=0)
    disp('mod(NRow,2) is not 0!');
    return;
end

% I quadrati possono avere dimensioni diverse alla fine e posizionati
% in posizione diversa. Occorre una matrice che definisca la posizione
% del quadrato e la sua dimensuione. E' UNA MATRICE SPARSA.
% Nella posizione i,j del vertice in alto a sinistra del quadrato si 
% mette la dimensione del quadrato.
% SI INIZIA CON 1 QUADRATO DI DIMENSIONE PARI A N x N

% Inizializza l'ouput: in QTD(i,j) c' la dimensione del quadrato con 
% l'angolo in alto a sinistra in (i,j) 
QTD=sparse(NRow,NCol);
QTD(1,1)=NRow;

% Plot time

% Plot original figure. Double buffer on, to see the current figure
F=figure(1);
set(F,'DoubleBuffer','On');
imagesc(RGBImage);
axis equal;
hold on;

% Ciclo per la quadtree decomposition
for Iter=1:NIter
    
    % Dimensione dei quadrati da analizzare
    DimensionUnderAnalysis=NRow/(2^(Iter-1));
    
    % Trova tutti i quadrati
%    [SquareRow,SquareCol]=find(QTD>0);
%   Nella prima iterazione N x N, con vertice nella posizione 1,1
    [SquareRow,SquareCol]=find(QTD==DimensionUnderAnalysis);
%   Nella prima iterazione un unico quadrato
    NSquares=length(SquareRow(:,1));
    
    % Per ogni quadrato trovato, verifica se c' da fare lo splitting
    for Square=1:NSquares
        
        % Dimensione del quadrato
        SquareDim=QTD(SquareRow(Square),SquareCol(Square));
        
        % Dati R, G, B del quadrato
        SquareDataR=RGBImage(SquareRow(Square):SquareRow(Square)+SquareDim-1,...
                             SquareCol(Square):SquareCol(Square)+SquareDim-1,1);
        SquareDataG=RGBImage(SquareRow(Square):SquareRow(Square)+SquareDim-1,...
                             SquareCol(Square):SquareCol(Square)+SquareDim-1,2);
        SquareDataB=RGBImage(SquareRow(Square):SquareRow(Square)+SquareDim-1,...
                             SquareCol(Square):SquareCol(Square)+SquareDim-1,3);
            
        % Distanze massime dal colore medio del quadrato
        DeltaR=double(max(SquareDataR(:)))-double(min(SquareDataR(:)));
        DeltaG=double(max(SquareDataG(:)))-double(min(SquareDataG(:)));
        DeltaB=double(max(SquareDataB(:)))-double(min(SquareDataB(:)));
        DeltaRGB=max([DeltaR DeltaG DeltaB]);
                    
        % Controllo per lo splitting e creazione di nuovi qaudrati se
        % necesario
        if (DeltaRGB>MaxDeltaRGB)
            
            % Creazione nuovi quadrati
            NewSquareDim=SquareDim*0.5;
            QTD(SquareRow(Square),SquareCol(Square))=NewSquareDim;
            QTD(SquareRow(Square)+NewSquareDim,SquareCol(Square))=NewSquareDim;
            QTD(SquareRow(Square),SquareCol(Square)+NewSquareDim)=NewSquareDim;
            QTD(SquareRow(Square)+NewSquareDim,SquareCol(Square)+NewSquareDim)=NewSquareDim;
            
            % Plot time
            rectangle('Position',[SquareCol(Square) SquareRow(Square) NewSquareDim NewSquareDim],'EdgeColor','r');
            rectangle('Position',[SquareCol(Square)+NewSquareDim SquareRow(Square) NewSquareDim NewSquareDim],'EdgeColor','r');
            rectangle('Position',[SquareCol(Square) SquareRow(Square)+NewSquareDim NewSquareDim NewSquareDim],'EdgeColor','r');
            rectangle('Position',[SquareCol(Square)+NewSquareDim SquareRow(Square)+NewSquareDim NewSquareDim NewSquareDim],'EdgeColor','r');
            
        end
        
        pause(0.01);
    end
end

% Plot time
hold off;

% Plot time
F=figure(2);
set(F,'DoubleBuffer','On');
subplot (1,2,1);
imagesc(RGBImage);
axis equal;
axis off;
title('Original');

% Creazione immagine clusterizzata
ClusterizedImage=uint8(zeros(NRow,NCol,3));
for Row=1:NRow
    for Col=1:NCol
        
        % Controlla se c' un quadrato
        if (QTD(Row,Col)>0)
            
            % Immagine locale del quadrato
            LocalImage=RGBImage(Row:Row+QTD(Row,Col)-1,Col:Col+QTD(Row,Col)-1,:);
            
            % Calcola il valore medio di RGB
            LocalImageR=LocalImage(:,:,1);
            MeanR=mean(LocalImageR(:));
            LocalImageG=LocalImage(:,:,2);
            MeanG=mean(LocalImageG(:));
            LocalImageB=LocalImage(:,:,3);
            MeanB=mean(LocalImageB(:));
            
            % Assegna il valore RGB nell'immagine clusterizzata
            ClusterizedImage(Row:Row+QTD(Row,Col)-1,Col:Col+QTD(Row,Col)-1,1)=MeanR;
            ClusterizedImage(Row:Row+QTD(Row,Col)-1,Col:Col+QTD(Row,Col)-1,2)=MeanG;
            ClusterizedImage(Row:Row+QTD(Row,Col)-1,Col:Col+QTD(Row,Col)-1,3)=MeanB;
            
            % Plot time
            subplot(1,2,2);
            imagesc(ClusterizedImage);
            axis equal;
            title('Clusterized');
            axis off;
            pause(0.01);
            
        end
    end
end

    